/// This dofile imports and cleans raw data, fills in missing values, and merges the data to produce "${cleaned}/CLEANED.dta" for analysis

****WB Court Budget (National Budget Document)****
import excel "${raw}/Court Budget_Percentage of GDP_v5_Updated URLs.xlsx", sheet("ALL - Consolidated") firstrow case(lower) clear
//Format
keep if source!="CEPEJ" & source!="ODI - IMF Law Courts" & source!="IMF GFS" & source!="ODI - National budget" & source!="Budget information shared with CEPEJ"
replace source="National Budget Document"
keep country code courtbudgetasofgdp year source
keep if inlist(code,"COD","GHA","MOZ","UGA")
rename courtbudgetasofgdp budget_gdp
label variable country "Country Name"
label variable code "Country Code"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
order country code year budget_gdp source
//Save as .dta
save "${cleaned}/WB_NBD.dta", replace

****COFOG Court Budget****
import excel "${raw}/Expenditure_by_Functions_of_Governm.xlsx", sheet("Data") cellrange(A1:BH2) firstrow clear
drop A
xpose, clear varname format
rename v1 budget_gdp
rename _varname country
//Generate country code
keep if country=="Kenya"
generate code="KEN"
//Format
replace budget_gdp=budget_gdp/100
gen source="COFOG"
label variable country "Country Name"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
label variable code "Country Code"
gen year=2020
label variable year "Year"
order country code year budget_gdp source
//Save as .dta
save "${cleaned}/COFOG.dta", replace

****ODI Court Budget****
import excel "${raw}/Domestic_Financing_Data_-_for_website.xlsx", sheet("Summary data") cellrange(B2:R443) firstrow case(lower) clear
//Generate budget_gdp
drop if n==.
generate budget_gdp= real(govrevgdp)*n/10000
//Format
keep if inlist(code,"MLI","SLE","SSD")
keep if year=="2020" | year=="FY 2020" |year=="20/21" |year=="FY 20/21"
drop year
gen year=2020
keep economy code budget_gdp year
rename economy country
gen source="ODI"
label variable country " Country Name"
label variable code "Country Code"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
label variable year "Year"
//Save as .dta
save "${cleaned}/ODI.dta", replace

****BOOST Court Budget****
//Prepare GDP in LCU for budget/GDP calculation
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (1).xlsx", sheet("Data") firstrow case(lower) clear
keep countryname countrycode yr2020
rename countryname country
rename countrycode code
rename yr2020 gdp_lcu
label variable gdp_lcu "GDP (LCU 2020)"
drop if code==""
save "${cleaned}/WB_GDP_LCU.dta", replace
//Import BOOST court budget data
import excel "${raw}/boost.xlsx", firstrow case(lower) clear
keep code country r
set type double
generate budget=real(r)
drop if budget==.
keep if code=="LBR"
//Merge with WB_GDP_LCU.dta
merge 1:1 code using "${cleaned}/WB_GDP_LCU.dta", keep(3) nogen
gen budget_gdp= budget/real(gdp_lcu)
drop if budget_gdp==.
//Format
gen year=2020
gen source="BOOST"
keep country code year budget_gdp source
order country code year budget_gdp source
label variable country "Country Name"
label variable code "Country Code"
label variable year "Year"
label variable source "Data Source"
label variable budget_gdp "Budget as a Share of GDP"
//Save as .dta
save "${cleaned}/BOOST.dta", replace

****WEO Government Expenditure****
import delimited "${raw}/WEOApr2024all.xls", clear 
///Keep government expenditure
keep iso country subjectdescriptor units v50
keep if subjectdescriptor=="General government total expenditure"
keep if units=="Percent of GDP"
//Format
keep iso country v50
rename iso code
rename v50 weo_gov_exp_gdp_100
gen year=2020
gen source="WEO"
label variable code "Country Code"
keep if inlist(code,"SSD","LBR","GHA","MOZ","MLI","UGA","KEN") | ///
       inlist(code,"COD","SLE")
label variable country "Country Name"
label variable weo_gov_exp_gdp_100 "Government Total Expenditure as Percent of GDP"
label variable year "Year"
label variable source "Data Source"
save "${cleaned}/WEO_GOV_EXP.dta", replace

****WB Government Expenditure****
import excel "${raw}/P_Data_Extract_From_World_Development_Indicators (4).xlsx", sheet("Data") firstrow case(lower) clear
keep countryname countrycode yr2020
rename countryname country
rename countrycode code
keep if inlist(code,"SSD","LBR","GHA","MOZ","MLI","UGA","KEN") | ///
       inlist(code,"COD","SLE")
rename yr2020 wb_gov_exp_gdp_100
drop if code==""
label variable wb_gov_exp_gdp_100 "General government final consumption expenditure (% of GDP)"
gen source="WB"
label variable source "Data Source"
save "${cleaned}/WB_GOV_EXP.dta", replace

****Cleaned data****
//Merge all sources
clear
append using "${cleaned}/BOOST.dta"
append using "${cleaned}/COFOG.dta"
append using "${cleaned}/ODI.dta"
append using "${cleaned}/WB_NBD.dta"
order code country year budget_gdp source
merge m:1 code using "${cleaned}/WEO_GOV_EXP.dta", keep(1 3) nogen
merge m:1 code using "${cleaned}/WB_GOV_EXP.dta", keep(1 3) nogen
//Generate the "Court Budget as % of Gov't Exp.", prioritising WB govn't expenditure
gen budget_gov_exp_100_weo= budget_gdp*10000/real(weo_gov_exp_gdp_100)
gen budget_gov_exp_100_wb= budget_gdp*10000/real(wb_gov_exp_gdp_100)
generate budget_gov_exp_100_wb_weo= budget_gov_exp_100_wb
replace budget_gov_exp_100_wb_weo= budget_gov_exp_100_weo if budget_gov_exp_100_wb==. & budget_gov_exp_100_weo!=.
//Format
label variable budget_gov_exp_100_wb_weo "Court Budget as % of Gov't Exp."
rename budget_gov_exp_100_wb_weo court_gov2020
keep code country year source court_gov2020
save "${cleaned}/CLEANED.dta", replace
